@@ -14,8 +14,6 @@ import logging
 # hwrt modules
 import hwrt
 import hwrt.utils as utils
-import hwrt.preprocessing as preprocessing
-import hwrt.features as features
 
 
 # Global variables
@@ -126,13 +124,7 @@ def worker():
         except ValueError:
             return "Invalid JSON string: %s" % raw_data_json
 
-        # Submit recorded json to database
-        submit_recording(raw_data_json)
-
         # Classify
-        # model_path = pkg_resources.resource_filename('hwrt', 'misc/')
-        # model = os.path.join(model_path, "model.tar")
-        # results = utils.evaluate_model_single_recording(model, raw_data_json)
         evaluate = utils.evaluate_model_single_recording_preloaded
         results = evaluate(preprocessing_queue,
                            feature_list,
@@ -161,9 +153,6 @@ def main():
     model_file = os.path.join(model_path, "model.tar")
     (preprocessing_queue, feature_list, model,
      output_semantics) = utils.load_model(model_file)
-    logging.info("Features:")
-    preprocessing.print_preprocessing_list(preprocessing_queue)
-    features.print_featurelist(feature_list)
     logging.info("Start webserver...")
     app.run()
 
